@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
-# Copyright 2018 The Knative Authors
+# Copyright 2020 The Knative Authors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,18 +17,16 @@
 # Documentation about this script and how to use it can be found
 # at https://github.com/knative/test-infra/tree/master/ci
 
-source $(dirname $0)/../vendor/knative.dev/test-infra/scripts/release.sh
+source $(dirname $0)/../vendor/knative.dev/hack/release.sh
 
 export GO111MODULE=on
 
 # Yaml files to generate, and the source config dir for them.
 declare -A COMPONENTS
 COMPONENTS=(
-  ["appender.yaml"]="config/tools/appender"
-  ["event-display.yaml"]="config/tools/event-display"
-  ["kafka-source.yaml"]="kafka/source/config"
-  ["kafka-channel.yaml"]="kafka/channel/config"
-  ["websocket-source.yaml"]="config/tools/websocket-source"
+  ["channel-consolidated.yaml"]="config/channel/consolidated"
+  ["channel-distributed.yaml"]="config/channel/distributed"
+  ["source.yaml"]="config/source"
 )
 readonly COMPONENTS
 
