@@ -1,6 +1,6 @@
 #!/bin/bash
 
-# Usage: create-release-branch.sh v0.9.0 release-v0.9.0
+# Usage: create-release-branch.sh v0.4.1 release-0.4
 
 set -e # Exit immediately on error.
 
@@ -11,15 +11,15 @@ target=$2
 git fetch upstream --tags
 git checkout -b "$target" "$release"
 
-# Update openshift's master and take all needed files from there.
+# Copy the openshift extra files from the OPENSHIFT/master branch.
 git fetch openshift master
-git checkout openshift/master -- openshift OWNERS_ALIASES OWNERS Makefile
+git checkout openshift/master -- openshift OWNERS Makefile
 make generate-dockerfiles
-make RELEASE=$release generate-kafka
-git add openshift OWNERS_ALIASES OWNERS Makefile
+make RELEASE=$release generate-release
+git add openshift OWNERS Makefile
 git commit -m "Add openshift specific files."
 
 # Apply patches .
 git apply openshift/patches/*
-make RELEASE=$release generate-kafka
+make RELEASE=$release generate-release
 git commit -am ":fire: Apply carried patches."
