@@ -18,21 +18,21 @@ limitations under the License.
 package e2e
 
 import (
+	"context"
 	"testing"
 
 	"knative.dev/eventing/test/e2e/helpers"
 )
 
 func TestBrokerChannelFlowTriggerV1BrokerV1(t *testing.T) {
-	helpers.BrokerChannelFlowWithTransformation(t, "MTChannelBasedBroker", "v1", "v1", channelTestRunner)
+	helpers.BrokerChannelFlowWithTransformation(context.Background(), t, "MTChannelBasedBroker", "v1", "v1", channelTestRunner)
 }
 func TestBrokerChannelFlowV1Beta1BrokerV1(t *testing.T) {
-	t.Skip("potential flake")
-	helpers.BrokerChannelFlowWithTransformation(t, "MTChannelBasedBroker", "v1", "v1beta1", channelTestRunner)
+	helpers.BrokerChannelFlowWithTransformation(context.Background(), t, "MTChannelBasedBroker", "v1", "v1beta1", channelTestRunner)
 }
 func TestBrokerChannelFlowTriggerV1Beta1BrokerV1Beta1(t *testing.T) {
-	helpers.BrokerChannelFlowWithTransformation(t, "MTChannelBasedBroker", "v1beta1", "v1beta1", channelTestRunner)
+	helpers.BrokerChannelFlowWithTransformation(context.Background(), t, "MTChannelBasedBroker", "v1beta1", "v1beta1", channelTestRunner)
 }
 func TestBrokerChannelFlowTriggerV1BrokerV1Beta1(t *testing.T) {
-	helpers.BrokerChannelFlowWithTransformation(t, "MTChannelBasedBroker", "v1beta1", "v1", channelTestRunner)
+	helpers.BrokerChannelFlowWithTransformation(context.Background(), t, "MTChannelBasedBroker", "v1beta1", "v1", channelTestRunner)
 }
